@@ -1,8 +1,8 @@
 import json
+import logging
 
 import requests
 from noteread.legado.shelf.base import BookSource
-from notetool.log import logger
 from tqdm import tqdm
 
 
@@ -14,4 +14,4 @@ def load_from_url(urls=None, cate1='1', book: BookSource = None):
             for line in json.loads(text):
                 book.add_json(json.dumps(line), cate1=cate1)
         except Exception as e:
-            logger.error(e)
+            logging.error(e)
